Event dispatching - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Event dispatching

Betty communicates with its components through an approach called event dispatching. Calling code that wants to let other components know something has happened, will tell the event dispatcher to dispatch an event. For each event type, handlers may be registered to be notified whenever an event of that type is dispatched.

At the moment, only extensions can register event handlers.

## Built-in event types

- `betty.load.LoadAncestryEvent`

- `betty.load.PostLoadAncestryEvent`

- `betty.generate.GenerateSiteEvent`